# Desired capabilities example file for BrowserStack
# Generate from https://www.browserstack.com/automate/capabilities
desired_cap = {
    "os": "Windows",
    "os_version": "11",
    "browser": "Chrome",
    "browser_version": "101.0",
    "browserstack.local": "false",
    "browserstack.debug": "true",
    "browserstack.selenium_version": "4.1.2",
}
